# FlaxSpeaker

 A simple speaker recognition library in [JAX](https://jax.readthedocs.io) and [Flax](https://flax.readthedocs.io).

 For the PyTorch version, see: [SpeakerRecognitionFromScratch](https://github.com/wq2012/SpeakerRecognitionFromScratch)
